@@ -25,3 +25,11 @@ except ImportError:
     IS_PLONE_3 = False
 else:
     IS_PLONE_3 = True
+
+# Turn-ON/OFF portal_catalog
+# updating on product installation
+
+# NOT REBUILD catalog
+UPDATE_CATALOG = False
+# DO REBUILDING catalog
+# UPDATE_CATALOG = True
